@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2010 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2011 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -35,9 +35,11 @@ USA.
 #include "argtable2.h"
 
 #ifdef WIN32
-# define FILESEPARATOR '\\'
+# define FILESEPARATOR1 '\\'
+# define FILESEPARATOR2 '/'
 #else
-# define FILESEPARATOR '/'
+# define FILESEPARATOR1 '/'
+# define FILESEPARATOR2 '/'
 #endif
 
 /* local error codes */
@@ -54,21 +56,49 @@ static void resetfn(struct arg_file *parent)
 /* Returns ptr to the base filename within *filename */
 static const char* arg_basename(const char *filename)
     {
-    const char *result = (filename ? strrchr(filename,FILESEPARATOR) : NULL);
-    if (result)
-        result++;
-    else
-        result = filename;
+    const char *result=NULL, *result1, *result2;
+
+    /* Find the last occurrence of eother file separator character. */
+    /* Two alternative file separator chars are supported as legal  */
+    /* file separators but not both together in the same filename.  */
+    result1 = (filename ? strrchr(filename,FILESEPARATOR1) : NULL);
+    result2 = (filename ? strrchr(filename,FILESEPARATOR2) : NULL);
+
+    if (result2)
+        result=result2+1;   /* using FILESEPARATOR2 (the alternative file separator) */
+
+    if (result1)
+        result=result1+1;   /* using FILESEPARATOR1 (the preferred file separator) */
+
+    if (!result)
+        result = filename;  /* neither file separator was found so basename is the whole filename */
+
+    /* special cases of "." and ".." are not considered basenames */
+    if (result && ( strcmp(".",result)==0 || strcmp("..",result)==0 ))
+       result = filename + strlen(filename);
+
     return result;
     }
 
 
-/* Returns ptr to the file extension within *filename */
-static const char* arg_extension(const char *filename)
+/* Returns ptr to the file extension within *basename */
+static const char* arg_extension(const char *basename)
     {
-    const char *result = (filename ? strrchr(filename,'.') : NULL);
-    if (filename && !result)
-        result = filename+strlen(filename);
+    /* find the last occurrence of '.' in basename */
+    const char *result = (basename ? strrchr(basename,'.') : NULL);
+
+    /* if no '.' was found then return pointer to end of basename */
+    if (basename && !result)
+        result = basename+strlen(basename);
+
+    /* special case: basenames with a single leading dot (eg ".foo") are not considered as true extensions */
+    if (basename && result==basename)
+        result = basename+strlen(basename);
+
+    /* special case: empty extensions (eg "foo.","foo..") are not considered as true extensions */
+    if (basename && result && result[1]=='\0')
+        result = basename+strlen(basename);
+
     return result;
     }
 
@@ -93,7 +123,7 @@ static int scanfn(struct arg_file *parent, const char *argval)
         {
         parent->filename[parent->count]  = argval;
         parent->basename[parent->count]  = arg_basename(argval);
-        parent->extension[parent->count] = arg_extension(argval);
+        parent->extension[parent->count] = arg_extension(parent->basename[parent->count]); /* only seek extensions within the basename (not the file path)*/
         parent->count++;
         }
 
