@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2010 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2011 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -800,7 +800,7 @@ void arg_print_gnuswitch(FILE *fp, struct arg_hdr **table)
         suffix="]";
         }
 
-    fprintf(fp,suffix);
+    fprintf(fp,"%s",suffix);
     }
 
 
