@@ -174,6 +174,39 @@ void test_argc_zero(void)
     }
 
 
+void test_initial_strings(void)
+    {
+    struct arg_str  *defines = arg_strn("D","define","MACRO",0,3, "macro definitions");
+    struct arg_file *outfile = arg_filen("o",NULL,"<output>",0,5, "output file (default is \"-\")");
+    struct arg_end  *end     = arg_end(20);
+    void* argtable[]  = {defines,outfile,end};
+    int i;
+
+    printf("testing initial strings...\n");
+    
+    /* arg_str: assert initial string values are "" */
+    for (i=0; i<defines->hdr.maxcount; i++)
+        {
+        assert( strcmp(defines->sval[i],"") == 0 ); 
+        printf("defines->sval[%d] == \"\" OK\n",i);
+        }
+
+    /* arg_file: assert initial string values are "" */
+    for (i=0; i<outfile->hdr.maxcount; i++)
+        {
+        assert( strcmp(outfile->filename[i],"") == 0 );  
+        printf("outfile->filename[%d]  == \"\" OK\n",i);
+        assert( strcmp(outfile->basename[i],"") == 0 );  
+        printf("outfile->basename[%d]  == \"\" OK\n",i);
+        assert( strcmp(outfile->extension[i],"") == 0 );  
+        printf("outfile->extension[%d] == \"\" OK\n",i);
+        }
+
+    /* deallocate each non-null entry in argtable[] */
+    arg_freetable(argtable,sizeof(argtable)/sizeof(argtable[0]));    
+    }
+
+
 int main(int argc, char **argv)
     {
     test_freetable();
@@ -181,6 +214,7 @@ int main(int argc, char **argv)
     test_arg_print_glossary();
     test_printsyntax();
     test_argc_zero();
+    test_initial_strings();
 
     /* close stdin and stdout to stop memcheck whining about their memory not being freed */
     fclose(stdin);
